---
layout: default
title: qudi-core
has_children: true
---

# Welcome to the qudi documentation

---
[![License: LGPL v3](https://img.shields.io/badge/License-LGPL%20v3-blue.svg)](https://www.gnu.org/licenses/lgpl-3.0)

### [Getting Started](getting_started.md)

### [License](license.md)

### Setup
- [Installation](setup/installation.md)
- [Startup](setup/startup.md)
- [Jupyter Notebook Integration](setup/jupyter.md)

### Design Concepts
- [Measurement Modules (Hardware/Logic/GUI)](design_concepts/measurement_modules.md)
- [Status Variables](design_concepts/status_variables.md)
- [Config Options](design_concepts/config_options.md)
- [Connectors](design_concepts/connectors.md)
- [Configuration](design_concepts/configuration.md)
- [Hardware Interface](design_concepts/hardware_interface.md)
- Module Interfuse
- [Logging](design_concepts/logging.md)
- Integrated IPython Kernel
- [Remote Modules](design_concepts/remote_modules.md)
- Thread Manager
- Module Manager
- Main Application
- Module Servers
- Task Runner
- [Data Storage](core_elements/data_storage.md)
- Data Fit Models

### Programming Guidelines
- Code Style
- Writing qudi Modules
- Porting Old qudi Modules
- [Hardware With Multiple Interfaces](programming_guidelines/hardware_with_multiple_interfaces.md)
- Implementing Fit Models
- [Data Fitting Integration](programming_guidelines/data_fitting_integration.md)
- Contributing
- [Creating a release](programming_guidelines/creating_releases.md)

### Graphical Config Editor

